import React from 'react';
import { ChannelSearchFunctionParams, SearchInputProps } from './SearchInput';
import { DropdownContainerProps, SearchResultItemProps } from './SearchResults';
import { ChannelOrUserResponse } from './utils';
import type { ChannelFilters, ChannelOptions, ChannelSort, UserFilters, UserOptions, UserSort } from 'stream-chat';
import type { DefaultStreamChatGenerics } from '../../types/types';
export declare type SearchQueryParams<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = {
    channelFilters?: {
        filters?: ChannelFilters<StreamChatGenerics>;
        options?: ChannelOptions;
        sort?: ChannelSort<StreamChatGenerics>;
    };
    userFilters?: {
        filters?: UserFilters<StreamChatGenerics>;
        options?: UserOptions;
        sort?: UserSort<StreamChatGenerics>;
    };
};
export declare type ChannelSearchProps<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = {
    /** The type of channel to create on user result select, defaults to `messaging` */
    channelType?: string;
    /** Custom UI component to display all of the search results, defaults to accepts same props as: [DefaultDropdownContainer](https://github.com/GetStream/stream-chat-react/blob/master/src/components/ChannelSearch/SearchResults.tsx)  */
    DropdownContainer?: React.ComponentType<DropdownContainerProps<StreamChatGenerics>>;
    /** Custom handler function to run on search result item selection */
    onSelectResult?: (result: ChannelOrUserResponse<StreamChatGenerics>) => Promise<void> | void;
    /** Custom placeholder text to be displayed in the search input */
    placeholder?: string;
    /** Display search results as an absolutely positioned popup, defaults to false and shows inline */
    popupResults?: boolean;
    /** Custom UI component to display empty search results */
    SearchEmpty?: React.ComponentType;
    /** Boolean to search for channels as well as users in the server query, default is false and just searches for users */
    searchForChannels?: boolean;
    /** Custom search function to override default */
    searchFunction?: (params: ChannelSearchFunctionParams<StreamChatGenerics>, event: React.BaseSyntheticEvent) => Promise<void> | void;
    /** Custom UI component to display the search text input */
    SearchInput?: React.ComponentType<SearchInputProps<StreamChatGenerics>>;
    /** Custom UI component to display the search loading state */
    SearchLoading?: React.ComponentType;
    /** Object containing filters/sort/options overrides for user search */
    searchQueryParams?: SearchQueryParams<StreamChatGenerics>;
    /** Custom UI component to display a search result list item, defaults to and accepts same props as: [DefaultSearchResultItem](https://github.com/GetStream/stream-chat-react/blob/master/src/components/ChannelSearch/SearchResults.tsx) */
    SearchResultItem?: React.ComponentType<SearchResultItemProps<StreamChatGenerics>>;
    /** Custom UI component to display the search results header */
    SearchResultsHeader?: React.ComponentType;
};
/**
 * The ChannelSearch component makes a query users call and displays the results in a list.
 * Clicking on a list item will navigate you into a channel with the selected user. It can be used
 * on its own or added to the ChannelList component by setting the `showChannelSearch` prop to true.
 */
export declare const ChannelSearch: <StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics>(props: ChannelSearchProps<StreamChatGenerics>) => JSX.Element;
//# sourceMappingURL=ChannelSearch.d.ts.map